==> vue-testing-library-0.1.14.tgz: package/npm/__tests__/fetch.js <==
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _axios = require('axios');

var _axios2 = _interopRequireDefault(_axios);

var _ = require('../');

var _Fetch = require('./components/Fetch.vue');

var _Fetch2 = _interopRequireDefault(_Fetch);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

test('Fetch makes an API call and displays the greeting when load-greeting is clicked', (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee() {
  var _render, wrapper, getByText;

  return _regenerator2.default.wrap(function _callee$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          _axios2.default.get.mockImplementationOnce(function () {
            return _promise2.default.resolve({
              data: { greeting: 'hello there' }
            });
          });

          _render = (0, _.render)(_Fetch2.default, { props: { url: '/greeting' } }), wrapper = _render.wrapper, getByText = _render.getByText;

          // Act

          _.Simulate.click(getByText('Fetch'));

          _context.next = 5;
          return (0, _.wait)();

        case 5:

          expect(_axios2.default.get).toHaveBeenCalledTimes(1);
          expect(_axios2.default.get).toHaveBeenCalledWith('/greeting');
          expect(getByText('hello there').textContent).toBe('hello there');
          expect(wrapper.html()).toMatchSnapshot();

        case 9:
        case 'end':
          return _context.stop();
      }
    }
  }, _callee, undefined);
})));

==> vue-testing-library-0.2.1.tgz: package/npm/__tests__/fetch.js <==
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _axios = require('axios');

var _axios2 = _interopRequireDefault(_axios);

var _ = require('../');

var _Fetch = require('./components/Fetch.vue');

var _Fetch2 = _interopRequireDefault(_Fetch);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

test('Fetch makes an API call and displays the greeting when load-greeting is clicked', (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee() {
  var _render, html, getByText;

  return _regenerator2.default.wrap(function _callee$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          _axios2.default.get.mockImplementationOnce(function () {
            return _promise2.default.resolve({
              data: { greeting: 'hello there' }
            });
          });

          _render = (0, _.render)(_Fetch2.default, { props: { url: '/greeting' } }), html = _render.html, getByText = _render.getByText;

          // Act

          _.Simulate.click(getByText('Fetch'));

          _context.next = 5;
          return (0, _.wait)();

        case 5:

          expect(_axios2.default.get).toHaveBeenCalledTimes(1);
          expect(_axios2.default.get).toHaveBeenCalledWith('/greeting');
          expect(getByText('hello there').textContent).toBe('hello there');
          expect(html()).toMatchSnapshot();

        case 9:
        case 'end':
          return _context.stop();
      }
    }
  }, _callee, undefined);
})));
